@@ -3,7 +3,7 @@ package Padre::Task::Outline::Perl6;
 use strict;
 use warnings;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use base 'Padre::Task::Outline';
 
@@ -55,6 +55,7 @@ sub _get_outline {
 		my $symbol_type = 'package';
 		my $symbol_name = '';
 		my $symbol_line = -1;
+		my $symbol_suffix = '';
 		my $symbol_context = '';
 		my $context = 'GLOBAL';
 		for my $htoken (@tokens) {
@@ -78,8 +79,12 @@ sub _get_outline {
 					$symbol_type = "subroutines";
 					$symbol_name .= $buffer;
 					$symbol_line = $lineno;
-				} elsif($tree =~ /routine_declarator__\w+_\d+method method_def longname/) {
+				} elsif($tree =~ /routine_declarator__\w+_\d+method method_def (longname|$)/) {
 					# a method
+					if($buffer eq '!') {
+						# private method...
+						$symbol_suffix = " (private)";
+					}
 					$symbol_type = "methods";
 					$symbol_name .= $buffer;
 					$symbol_line = $lineno;
@@ -98,6 +103,12 @@ sub _get_outline {
 					$symbol_type = "regexes";
 					$symbol_name .= $buffer;
 					$symbol_line = $lineno;
+				} elsif($tree =~ /scope_declarator__\w+_\d+(our|my|has|state|constant) scoped declarator variable_declarator variable/) {
+					# a start for an attribute declaration
+					$symbol_type = "attributes";
+					$symbol_name .= $buffer;
+					$symbol_line = $lineno;
+					$symbol_suffix = $1;
 				} else {
 					if($symbol_name ne '') {
 						if( $symbol_type eq 'class' || 
@@ -115,6 +126,14 @@ sub _get_outline {
 							$cur_pkg->{name} = $symbol_name . " ($symbol_type)";
 							$cur_pkg->{line} = $symbol_line;
 						} else {
+							if($symbol_type eq 'attributes') {
+								if($symbol_name !~ /\./) {
+									$symbol_suffix = " (private, $symbol_suffix)";
+								} else {
+									$symbol_suffix = " ($symbol_suffix)";
+								}
+							}
+							$symbol_name .= $symbol_suffix;
 							push @{ $cur_pkg->{$symbol_type} }, {
 								name => $symbol_name, 
 								line=>$symbol_line,
@@ -123,6 +142,7 @@ sub _get_outline {
 						$symbol_type = '';
 						$symbol_name = '';
 						$symbol_line = -1;
+						$symbol_suffix = '';
 					}
 				}
 			}
@@ -236,7 +256,7 @@ sub _update_treectrl {
 				}
 			)
 		);
-		foreach my $type (qw(modules subroutines methods submethods macros regexes)) {
+		foreach my $type (qw(modules attributes subroutines methods submethods macros regexes)) {
 			_add_subtree( $outlinebar, $pkg, $type, $branch );
 		}
 		$outlinebar->Expand($branch);
@@ -259,7 +279,7 @@ sub _add_subtree {
 		);
 
 		my @sorted_entries = ();
-		if ( $type eq 'subroutines' || $type eq 'methods' || $type eq 'submethods' || $type eq 'macros') {
+		if ( $type eq 'subroutines' || $type eq 'methods' || $type eq 'submethods' || $type eq 'macros' || $type eq 'attributes') {
 			my $config = Padre->ide->config;
 			if ( $config->main_functions_order eq 'original' ) {
 
@@ -299,7 +319,8 @@ sub _add_subtree {
 			$type eq 'methods' || 
 			$type eq 'submethods' || 
 			$type eq 'macros' || 
-			$type eq 'regexes') 
+			$type eq 'regexes' ||
+			$type eq 'attributes') 
 		{
 			$outlinebar->Expand($type_elem);
 		} else {
